@@ -152,6 +152,7 @@ class CaptureManager:
         item.add_report_section(when, "stdout", out)
         item.add_report_section(when, "stderr", err)
 
+
 error_capsysfderror = "cannot use capsys and capfd at the same time"
 
 
@@ -455,6 +456,13 @@ class DontReadFromInput:
     def close(self):
         pass
 
+    @property
+    def buffer(self):
+        if sys.version_info >= (3,0):
+            return self
+        else:
+            raise AttributeError('redirected stdin has no attribute buffer')
+
 
 def _readline_workaround():
     """
